﻿-- Author      : kevin.ortman
-- Create Date : 12/27/2008 2:38:24 PM

local name, link, quality, ilevel, reqlevel, itype, isubtype, maxstack, equipslot, texture

-- Tooltip hooking based on SellFish by Tuller.

local function IsBagSlot(slot)
	return slot >= 20 and slot <= 23 or slot >= 68
end

local hooks = {
	SetHyperlink = function(link)
		return link
	end,

	SetBagItem = function(bag, slot)
		if not MerchantFrame:IsVisible() then
			return GetContainerItemLink(bag, slot)
		end
	end,

	SetInventoryItem = function(unit, slot)
		return GetInventoryItemLink(unit, slot)
	end,

	SetLootItem = function(slot)
		if LootSlotIsItem(slot) then
			return GetLootSlotLink(slot)
		end
	end,

	SetLootRollItem = function(slot)
		return GetLootRollItemLink(slot)
	end,

	SetAuctionItem = function(type, index)
		return GetAuctionItemLink(type, index)
	end,

	SetAuctionSellItem = function()
		return select(2, GetItemInfo(GetAuctionSellItemInfo()))
	end,

	SetTradeSkillItem = function(skill, id)
		if id then
			return GetTradeSkillReagentItemLink(skill, id)
		end
		return GetTradeSkillItemLink(skill)
	end,

	SetQuestItem = function(type, index)
		return GetQuestItemLink(type, index)
	end,

	SetQuestLogItem = function(type, index)
		return GetQuestLogItemLink(type, index)
	end,

	SetTradePlayerItem = function(id)
		return GetTradePlayerItemLink(id)
	end,

	SetTradeTargetItem = function(id)
		return GetTradeTargetItemLink(id)
	end,

	SetInboxItem = function(id)
		return GetInboxItemLink(id)
	end,

	SetSendMailItem = function(id)
		return select(2, GetItemInfo(GetSendMailItem(id)))
	end,
}


GuildWork.ToolTipHooks = {}

function GuildWork.ToolTipHooks:AddInfoToTooltip(tip, link)
	name, link, quality, ilevel, reqlevel, itype, isubtype, maxstack, equipslot, texture = GetItemInfo(link)
	
	if link then
		for charName, rank in pairs(GuildWork:GetItemWishList(name)) do
			tip:AddDoubleLine(charName, rank, 1,0,0, 1,0,0)
		end		
	end
	
	tip:Show()
end

function GuildWork.ToolTipHooks:HookTip(tooltip, method, action)
	hooksecurefunc(tooltip, method, function(tip, ...)
		local link = action(...)
		if link then
			GuildWork.ToolTipHooks:AddInfoToTooltip(tip, link)
		end
	end)
end

function GuildWork.ToolTipHooks:RegisterHooks()
	for method,func in pairs(hooks) do
		GuildWork.ToolTipHooks:HookTip(GameTooltip, method, func)
	end

	GuildWork.ToolTipHooks:HookTip(ItemRefTooltip, 'SetHyperlink', hooks.SetHyperlink)
end


